Aabb

Struct Aabb 

#[repr(C)]
pub struct Aabb { pub min: Vec3A, pub max: Vec3A, }
An Axis-Aligned Bounding Box (AABB) represented by its minimum and maximum points.

Fields

min: Vec3Amax: Vec3A

Implementations

Source

impl Aabb

pub const INVALID: Self

An invalid (empty) AABB with min set to the maximum possible value and max set to the minimum possible value.

pub const LARGEST: Self

An infinite AABB with min set to negative infinity and max set to positive infinity.

pub const INFINITY: Self

An infinite AABB with min set to negative infinity and max set to positive infinity.

pub fn new(min: Vec3A, max: Vec3A) -> Self

Creates a new AABB with the given minimum and maximum points.

pub fn from_point(point: Vec3A) -> Self

Creates a new AABB with both min and max set to the given point.

pub fn from_points(points: &[Vec3A]) -> Self

Creates an AABB that bounds the given set of points.

pub fn contains_point(&self, point: Vec3A) -> bool

Checks if the AABB contains the given point.

pub fn extend(&mut self, point: Vec3A) -> &mut Self

Extends the AABB to include the given point.

pub fn union(&self, other: &Self) -> Self

Returns the union of this AABB and another AABB.

pub fn intersection(&self, other: &Self) -> Self

Returns the intersection of this AABB and another AABB.

The intersection of two AABBs is the overlapping region that is common to both AABBs. If the AABBs do not overlap, the resulting AABB will have min and max values that do not form a valid box (min will not be less than max).

pub fn diagonal(&self) -> Vec3A

Returns the diagonal vector of the AABB.

pub fn center(&self) -> Vec3A

Returns the center point of the AABB.

pub fn center_axis(&self, axis: usize) -> f32

Returns the center coordinate of the AABB along a specific axis.

pub fn largest_axis(&self) -> usize

Returns the index of the largest axis of the AABB.

pub fn smallest_axis(&self) -> usize

Returns the index of the smallest axis of the AABB.

pub fn half_area(&self) -> f32

Returns half the surface area of the AABB.

pub fn surface_area(&self) -> f32

Returns the surface area of the AABB.

pub fn empty() -> Self

Returns an empty AABB.

pub fn valid(&self) -> bool

Checks if the AABB is valid (i.e., min <= max on all axes).

pub fn intersect_aabb(&self, other: &Aabb) -> bool

Checks if this AABB intersects with another AABB.

pub fn intersect_ray(&self, ray: &Ray) -> f32

Checks if this AABB intersects with a ray and returns the distance to the intersection point. Returns f32::INFINITY if there is no intersection.